@@ -36,10 +36,10 @@ void HistoryInfoWindow::load(QString name, QString group)
     while(!list.isEmpty())
     {
         set.setNum(j+1);
-        if(group != "Cardio")
+        if(group != "Cardio" && list.first() != "0")
             lblSet[j]->setText("Set " + set + ": " + list.takeFirst() +" " +
                                 list.takeFirst() + " reps - " + list.takeFirst());
-        else
+        else if(list.first() != "0")
             lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
                                 list.takeFirst() + " - " + list.takeFirst());
 
