@@ -217,7 +217,12 @@ void ListWindow::deleteItem()
 
      if(ret == QMessageBox::Ok)
      {
-         xml->removeElement(str);
+         if(group != "Cardio" && group != "Program")
+            xml->removeElement(str,"exercises");
+         else if(group == "Cardio")
+            xml->removeElement(str,"cardio");
+         else if (group == "Program")
+             xml->removeProgram(str);
      }
 }
 
@@ -227,10 +232,20 @@ void ListWindow::editItem()
     QList <QString> list;
     str = lstExercises->currentIndex().data().toString();
 
-    list = xml->openEx(str);
-    nw = new NewExerciseWindow(this);
-    nw->load(list.takeFirst(),list.takeFirst(),list.takeFirst(),list.takeFirst());
-    nw->show();
+    if(group == "Program")
+    {
+        list = xml->loadProgram(str);
+        npw = new NewProgramWindow(this);
+        npw->load(str,list);
+        npw->show();
+    }
+    else
+    {
+        list = xml->openEx(str);
+        nw = new NewExerciseWindow(this);
+        nw->load(list.takeFirst(),list.takeFirst(),list.takeFirst(),list.takeFirst());
+        nw->show();
+    }
 }
 
 void ListWindow::showExport()
