@@ -11,12 +11,13 @@ XML::XML()
 }
 
 
-void XML::removeElement(QString name)
+void XML::removeElement(QString name, QString filename)
 {
 
     QDomDocument doc( "Exercises" );
-    QString str = "/home/user/.qexercise";
-    QFile file( str + "/exercises.xml" );
+    QString str = "/home/user/.qexercise/";
+    str.append(filename);
+    QFile file( str + ".xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return;
@@ -57,6 +58,50 @@ void XML::removeElement(QString name)
     file.close();
 }
 
+void XML::removeIngredient(QString name)
+{
+    return;
+}
+
+void XML::removeProgram(QString name)
+{
+
+    QDomDocument doc( "Program" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/program.xml" );
+    if( !file.open( QIODevice::ReadOnly ) )
+    {
+        return;
+    }
+
+    doc.setContent(&file);
+    file.close();
+
+    QDomElement root = doc.documentElement();
+    if( root.tagName() != "programs" )
+    {
+      return;
+    }
+
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "program" )
+        {
+
+            if(name == e.attribute( "name", "" ))
+            {
+                root.removeChild(n);
+            }
+        }
+      }
+      n = n.nextSibling();
+   }
+}
+
 void XML::saveProgram(QString name, QModelIndexList exercises)
 {
     QDomDocument doc( "Program" );
@@ -82,7 +127,7 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
         {
             if(name == e.attribute( "name", "" ))
             {
-                removeElement(name);
+                removeProgram(name);
             }
         }
       }
@@ -660,7 +705,7 @@ void XML::saveEx(QString name, QString group, QString muscle,
         {
             if(name == e.attribute( "name", "" ))
             {
-                removeElement(name);
+                removeElement(name, "exercises");
                 qDebug () << "xml::saveEx 2";
             }
         }
@@ -721,7 +766,7 @@ void XML::saveCardio(QString name)
         {
             if(name == e.attribute( "name", "" ))
             {
-                removeElement(name);
+                removeElement(name,"cardio");
             }
         }
       }
@@ -930,7 +975,7 @@ void XML::saveFood(QString name, QString type, QString kcal, QString protein, QS
         {
             if(name == e.attribute( "name", "" ))
             {
-                removeElement(name);
+                removeIngredient(name);
             }
         }
       }
